(function ($) {
    'use strict';

    const el = wp.element.createElement;
    const { __ } = wp.i18n;
    const { registerBlockType } = wp.blocks;
    const { RichText, InspectorControls, MediaUpload} = wp.editor;
    const { TextControl, Button, PanelBody, SelectControl} = wp.components;


    registerBlockType( 'cp-smart-otp/gutenberg-subscribe-to-download', {
        title: __('Subscribe to download', CpOtp.cp_name),
        icon: 'universal-access-alt',
        category: 'cp-smart-otp',
        attributes: {
            title: {
                type: 'string',
                default: 'Vestibulum aliquet, felis vel suscipit ultrices, nunc mi !'
            },
            sub_title:{
                type: 'string',
                default: 'Proin odio felis, luctus facilisis interdum a, fringilla id quam. Vivamus metus dolor, rutrum at vulputate '
            },
            style: {
                type: 'string',
                default: 1
            },
            note: {
                type: 'string',
                source: 'html',
                selector: 'cpOtp-bottom',
                default: 'Curabitur porta posuere malesuada. Ut quam magna, semper vel arcu quis, tincidunt lobortis nulla.'
            },
            files: {
                type: 'array',
                default: []
            },
            fileIds: {
                type: 'string',
                source: 'meta',
                meta: 'cpOtp_subscribe_to_download'
            },
            verify_type: {
                type: 'string',
                default: 1
            }
        },

        edit: function( props ) {

            function onChangeTitle(val){
                return props.setAttributes({
                    title: val
                });
            }

            function onChangeSubTitle(val){
                return props.setAttributes({
                    sub_title: val
                });
            }

            function onChangeNote(val){
                return props.setAttributes({
                    note: val
                });
            }

            function onChangeStyle(val){
                return props.setAttributes({
                    style: val
                });
            }

            function onSelectMedia(obj) {
                var files = [];
                var fileIDs = [];
                for (var i=0,len = obj.length; i<len; i++){
                    files.push({
                        id: obj[i].id,
                        url: obj[i].url,
                        subtype: obj[i].subtype,
                        filename: obj[i].filename
                    });
                    fileIDs.push({id: i+1, value: obj[i].id});
                }
                return props.setAttributes({
                    files: files,
                    fileIds: JSON.stringify(fileIDs)
                });
            }

            function onRemoveItem(event) {
                var rInd = event.target.dataset.item;
                var files = props.attributes.files;
                var fileIDs = [];
                if(files.length){
                    files.splice(rInd, 1);
                }
                for (var i=0,len = files.length; i<len; i++){
                    fileIDs.push({id: i+1, value: files[i].id});
                }
                return props.setAttributes({
                    files: files,
                    fileIds: JSON.stringify(fileIDs)
                });
            }

            function onRenderMedia(obj) {
                var items = [];
                props.attributes.files.forEach(function (x, ind) {
                    items.push(
                        el(
                            'div',
                            {className: 'thumbnail ali-left'},
                            el(
                                'div',
                                {className: 'centered'},
                                el(
                                    'img',
                                    {
                                        src: (x.subtype === 'png' || x.subtype === 'jpg' || x.subtype === 'jpeg') ? x.url : CpOtp.includes_url + '/images/media/default.png',
                                        className: 'icon'
                                    }
                                )
                            ),
                            el(
                                'div',
                                {className: 'filename'},
                                el(
                                    'div',
                                    null,
                                    x.filename
                                )
                            ),
                            el(
                                'i',
                                {
                                    className: 'dashicons dashicons-trash',
                                    onClick: onRemoveItem,
                                    "data-item": ind
                                },
                            )
                        )
                    );
                });

                return !props.attributes.files.length ?
                    el(
                        Button,
                        {
                            className: 'cpOtp-button components-button is-default',
                            onClick: obj.open
                        },
                        __('Choose an files', CpOtp.cp_name)
                    ) : el(
                        'div',
                        {className: 'cpOtp-media-has-file'},
                        el(
                            'p',
                            {className: 'ali-left'},
                            __('Files', CpOtp.cp_name)
                        ),
                        items,
                        el(
                            Button,
                            {
                                className: 'cpOtp-button components-button is-default',
                                onClick: obj.open
                            },
                            __('Choose an files', CpOtp.cp_name)
                        )
                    );
            }

            function onChangeVerifyType(obj){
                return props.setAttributes({
                    verify_type: obj
                });
            }

            return [
                el(
                    InspectorControls,
                    null,
                    el(
                        PanelBody,
                        {
                            title: __('Options', CpOtp.cp_name),
                            initialOpen: true
                        },
                        el(
                            SelectControl,
                            {
                                label: __('Verify type', CpOtp.cp_name),
                                value: props.attributes.style,
                                onChange: onChangeVerifyType,
                                options: [
                                    {value: 1, label: __('Email', CpOtp.cp_name)},
                                    {value: 2, label: __('Phone', CpOtp.cp_name)}
                                ]
                            }
                        ),
                        el(
                            SelectControl,
                            {
                                label: __('Style', CpOtp.cp_name),
                                value: props.attributes.style,
                                onChange: onChangeStyle,
                                options: [
                                    {value: 1, label: __('Default', CpOtp.cp_name)},
                                    {value: 2, label: __('Style 1', CpOtp.cp_name)},
                                    {value: 3, label: __('Style 2', CpOtp.cp_name)},
                                    {value: 4, label: __('Style 3', CpOtp.cp_name)},
                                    {value: 5, label: __('Style 4', CpOtp.cp_name)},
                                    {value: 6, label: __('Style 5', CpOtp.cp_name)},
                                    {value: 7, label: __('Style 6', CpOtp.cp_name)}
                                ]
                            }
                        ),
                        el( MediaUpload, {
                            multiple: 'add',
                            onSelect: onSelectMedia,
                            type: 'file',
                            render: onRenderMedia
                        })
                    )
                ),
                el(
                    'div',
                    {className: 'cpOtp-subscribe-to-download cpOtp-style cpOtp-style-' + props.attributes.style},
                    el(
                        'div',
                        {className: 'cpOtp-top'},
                        el(
                            'div',
                            {className: 'cpOtp-top-icon'}
                        ),
                        el(
                            RichText,
                            {
                                tagName: 'h3',
                                className: 'cpOtp-title',
                                onChange: onChangeTitle,
                                value: props.attributes.title
                            }
                        ),
                        el(
                            RichText,
                            {
                                tagName: 'p',
                                className: 'cpOtp-sub-title',
                                onChange: onChangeSubTitle,
                                value: props.attributes.sub_title
                            }
                        )
                    ),
                    el(
                        'div',
                        {className: 'cpOtp-inner'},
                        el(
                            'div',
                            {className: 'cpOtp-body'},
                            props.attributes.verify_type == 1 ? el(
                                TextControl,
                                {
                                    type: 'email',
                                    className: 'cpOtp-input',
                                    placeholder: __('abc@gmail.com', CpOtp.cp_name)
                                }
                            ) : el(
                                TextControl,
                                {
                                    type: 'phone',
                                    className: 'cpOtp-input',
                                    placeholder: __('Type your phone number', CpOtp.cp_name)
                                }
                            ),
                            el(
                                'span',
                                {
                                    className: 'cpOtp-icon',
                                    onClick: 'CpOtp.subscribe_to_download(event, '+ CpOtp.object_id +', '+ props.attributes.verify_type +')'
                                }
                            )
                        ),
                        el(
                            'div',
                            {className: 'cpOtp-bottom'},
                            el(
                                'label',
                                {className: 'cpOtp-checkbox'},
                                el(
                                    'span'
                                ),
                                el(
                                    'input',
                                    {type: 'checkbox'}
                                ),
                                el(
                                    'span',
                                    {className: 'checkmark'}
                                ),
                            ),
                            el(
                                RichText,
                                {
                                    tagName: 'p',
                                    className: 'cpOtp-bottom',
                                    onChange: onChangeNote,
                                    value: props.attributes.note
                                }
                            ),
                        )
                    )
                )
            ];
        },

        save: function( props ) {

            return el(
                'div',
                {className: 'cpOtp-subscribe-to-download cpOtp-style cpOtp-style-' + props.attributes.style},
                el(
                    'div',
                    {className: 'cpOtp-top'},
                    el(
                        'div',
                        {className: 'cpOtp-top-icon'}
                    ),
                    el(
                        'h3',
                        {className: 'cpOtp-title'},
                        props.attributes.title
                    ),
                    el(
                        'p',
                        {className: 'cpOtp-sub-title'},
                        props.attributes.sub_title
                    )
                ),
                el(
                    'div',
                    {className: 'cpOtp-inner'},
                    el(
                        'div',
                        {className: 'cpOtp-body'},
                        props.attributes.verify_type == 1 ? el(
                            'input',
                            {
                                className: 'cpOtp-input',
                                placeholder: __('abc@gmail.com', CpOtp.cp_name)
                            }
                        ) : el(
                            'input',
                            {
                                className: 'cpOtp-input',
                                placeholder: __('Type your phone number', CpOtp.cp_name)
                            }
                        ),
                        el(
                            'span',
                            {
                                className: 'cpOtp-icon',
                                onClick: 'CpOtp.subscribe_to_download(event, '+ CpOtp.object_id +', '+ props.attributes.verify_type +')'
                            }
                        )
                    ),
                    el(
                        'div',
                        {className: 'cpOtp-bottom'},
                        el(
                            'label',
                            {className: 'cpOtp-checkbox'},
                            props.attributes.note,
                            el(
                                'input',
                                {type: 'checkbox'}
                            ),
                            el(
                                'span',
                                {className: 'checkmark'}
                            ),
                        )
                    )
                )
            );
        },
    } );

})(jQuery);
