<?php

class cpsmart_otp_cf7
{
    const FORM_NAME = 'Contact Form 7';

    public function __construct()
    {
        // Register Button On Render
        add_action('wpcf7_init', [$this, 'register_element'], 10, 1);

        // Register Button select on Admin
        add_action('wpcf7_admin_init', [$this, 'add_tag_to_list'], 19);

        // Validate on submit
        add_filter('wpcf7_validate_cpotp_button_email*', [$this, 'validate'], 10, 2);
        add_filter('wpcf7_validate_cpotp_button_phone*', [$this, 'validate'], 10, 2);
        add_filter('cpotp-js-variable', [$this, 'add_text_language'], 10, 2);
    }

    public function add_text_language($default)
    {
        $default['i18n']['cf7']['verify_canceled'] = __cp("Verify canceled.");

        return $default;
    }

    public function validate($result, $tag)
    {
        if (
            ($tag->basetype == 'cpotp_button_phone' && $tag->type == 'cpotp_button_phone*')
            ||
            ($tag->basetype == 'cpotp_button_email' && $tag->type == 'cpotp_button_email*')
        ) {
            $phone = isset($_POST['cpotp_button_phone']) ? $_POST['cpotp_button_phone'] : '';
            $email = isset($_POST['cpotp_button_email']) ? $_POST['cpotp_button_email'] : '';
            $cpItem = isset($_POST['cpotp_log_id']) ? $_POST['cpotp_log_id'] : '';

            $formId = isset($_POST['_wpcf7']) ? $_POST['_wpcf7'] : '';

            if (empty($cpItem)) {
                if (empty($phone) && empty($email)) {
                    $result->invalidate($tag, __cp("Please verify Phone or Email before."));
                } else {
                    $referral = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';

                    $idLog = cpsmart_otp_log::add_log_cf7([
                        'phone' => $phone,
                        'phone_prefix' => "",
                        'form_id' => isset($_POST['_wpcf7']) ? $_POST['_wpcf7'] : '',
                        'user_id' => "",
                        'email' => $email,
                        'referral' => $referral,
                    ]);

                    $dataSave = [];
                    foreach ($_POST as $key => $value) {
                        $dataSave[$key] = $value;
                    }
                    $dataSave['cpotp_log_id'] = $idLog;
                    cpsmart_otp_log::update_log_cf7($dataSave);
                }
            } else {
                $dataSave = [];
                foreach ($_POST as $key => $value) {
                    $dataSave[$key] = $value;
                }
                cpsmart_otp_log::update_log_cf7($dataSave);
            }
        }

        return $result;
    }

    public function register_element($tag)
    {
        wpcf7_add_form_tag(['cpotp_button_email', 'cpotp_button_email*'], [$this, 'render_button_verify'], array(
            'name-attr' => true
        ));

        wpcf7_add_form_tag(['cpotp_button_phone', 'cpotp_button_phone*'], [$this, 'render_button_verify'], array(
            'name-attr' => true
        ));
    }

    public function render_button_verify($tag)
    {
        $cpotp_phone = isset($_COOKIE['cpotp_phone']) ? $_COOKIE['cpotp_phone'] : '';
        $cpotp_email = isset($_COOKIE['cpotp_email']) ? $_COOKIE['cpotp_email'] : '';

        $value = isset($tag->values[0]) ? $tag->values[0] : '';
        $class = wpcf7_form_controls_class($tag->type);

        if (empty($value)) {
            if ($tag->basetype == 'cpotp_button_phone') {
                $value = __cp("Verify by Phone");
            } else {
                $value = __cp("Verify by Email");
            }
        }

        $attrButton = $attsInput = $atts = array();

        $attrButton['type'] = "button";

        $atts['class'] = 'wpcf7-form-control-wrap ' . sanitize_html_class($tag->name);
        $atts['id'] = $tag->get_id_option();


        if ($tag->is_required()) {
            $attsInput['aria-required'] = 'true';
        }
        $attsInput['type'] = 'hidden';


        if ($tag->basetype == 'cpotp_button_phone') {
            $attrButton['class'] = $tag->get_class_option($class) . ' cpotp-cf7-phone';
            $attrButton['onclick'] = "CpOtp.fblogin_sms(event)";
            $attrButton['data-country-code'] = cp_otp_helper::get_country_code();
            $attsInput['name'] = 'cpotp_button_phone';
        } else {
            $attrButton['class'] = $tag->get_class_option($class) . ' cpotp-cf7-email';
            $attrButton['onclick'] = "CpOtp.fblogin_email(event)";
            $attsInput['name'] = 'cpotp_button_email';
        }
        $attrButton['class'] .= " cpotp_button_cf7";

        if (!empty($cpotp_email) || !empty($cpotp_phone)) {
            unset($attrButton['onclick']);
            if (!empty($cpotp_phone) && $tag->basetype == 'cpotp_button_phone') {
                $attsInput['value'] = $cpotp_phone;
            } elseif (!empty($cpotp_email) && $tag->basetype == 'cpotp_button_phone') {
                $attsInput['value'] = $cpotp_email;
            }

            $attrButton['type'] = 'submit';
        } else {
            wp_enqueue_script('fb-account-kit');
            wp_enqueue_script('cpotp-process-cf7');
        }

        $atts = wpcf7_format_atts($atts);
        $attrButton = wpcf7_format_atts($attrButton);
        $attsInput = wpcf7_format_atts($attsInput);

        $html = sprintf('<span %1$s><button %2$s >%3$s</button><input %4$s /></span>', $atts, $attrButton, $value, $attsInput);
        return $html;
    }

    public function add_tag_to_list()
    {
        $tag_generator = WPCF7_TagGenerator::get_instance();
        $tag_generator->add('cpotp_button_phone', __cp('cpotp_button_phone'), [$this, 'box_options']);
        $tag_generator->add('cpotp_button_email', __cp('cpotp_button_email'), [$this, 'box_options']);
    }

    public function box_options($contact_form, $args = '')
    {
        $args = wp_parse_args($args, array()); ?>

        <div class="control-box">
            <fieldset>
                <table class="form-table">
                    <tbody>
                    <tr>
                        <th scope="row">
                            <label for="<?php echo esc_attr($args['content'] . '-values'); ?>">
                                <?php echo esc_html__('Label', 'contact-form-7'); ?></label>
                        </th>
                        <td>
                            <input type="text" name="values" class="oneline"
                                   id="<?php echo esc_attr($args['content'] . '-values'); ?>"/>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </fieldset>
        </div>

        <div class="insert-box">
            <input type="text" name="<?php echo esc_attr($args['title']); ?>" class="tag code" readonly="readonly"
                   onfocus="this.select()"/>
            <div class="submitbox">
                <input type="button" class="button button-primary insert-tag"
                       value="<?php echo esc_attr__('Insert Tag', 'contact-form-7'); ?>"/>
            </div>
        </div>
        <?php
    }
}

new cpsmart_otp_cf7();
