<?php

use CastPlugin\CpAdminNotice;
use CastPlugin\CpCore;

class cpsmart_otp_core
{
    public $plugin;

    public function __construct(cpsmart_otp $plugin)
    {
        require_once CPOTP_PATH . "/includes/class-cp-templates.php";
        require_once CPOTP_PATH . "/includes/class-cpotp-wp-login.php";
        require_once CPOTP_PATH . "/includes/class-cpotp-page-setting.php";
        require_once CPOTP_PATH . "/includes/class-cp-log.php";
        require_once CPOTP_PATH . "/includes/class-cp-ajax.php";
        require_once CPOTP_PATH . "/includes/class-cp-woo.php";
        require_once CPOTP_PATH . "/includes/class-cp-cf7.php";

        //v1.2
        require_once CPOTP_PATH . "/includes/class-cp-download-handler.php";
        require_once CPOTP_PATH . "/includes/class-cpotp-helper.php";
        require_once CPOTP_PATH . "/includes/class-cpotp-export.php";
        require_once CPOTP_PATH . "/includes/class-cpotp-gutenberg.php";
        require_once CPOTP_PATH . "/includes/class-cpotp-shortcode-login.php";


        $this->plugin = $plugin;

        $plugin->get_loader()->add_action('plugins_loaded', $this, 'run', 1);

        $plugin->get_loader()->add_action('wp_enqueue_scripts', $this, 'register_script', 1);
        $plugin->get_loader()->add_action('admin_enqueue_scripts', $this, 'register_script', 1);
        $plugin->get_loader()->add_action('login_enqueue_scripts', $this, 'register_script', 1);
        $plugin->get_loader()->add_action('admin_init', $this, 'valid_setting', 1);

        $plugin->run();
    }

    public function valid_setting()
    {
        $cp_otp_options = cp_otp_page_setting::get_options();

        if (
            (!isset($cp_otp_options['app_id']) || empty($cp_otp_options['app_id']))
            || (!isset($cp_otp_options['app_version']) || empty($cp_otp_options['app_version']))
            || (!isset($cp_otp_options['app_secret']) || empty($cp_otp_options['app_secret']))
        ) {
            $cpAdminNotice = new CpAdminNotice();
            $cpAdminNotice->warning(__cp("It seems that you didn't config Facebook Account Kit properly, please read the documentation <a href='https://catsplugins.com/documentation/smart-otp/#setup-facebook-api-token' target='_blank'>here.</a>"));
        }
    }

    public function register_script()
    {
        $versionAsset = CPOTP_VERSION;

        $versionAsset = time(); // Only Developer

        $redirect_to = isset($_GET['redirect_to']) ? esc_url_raw($_GET['redirect_to']) : '';
        if (empty($redirect_to)) {
            $redirect_to = get_edit_profile_url();
        }
        $redirect_to = apply_filters('login_redirect', $redirect_to);

        $cp_otp_options = cp_otp_page_setting::get_options();

        wp_register_script('fb-account-kit', 'https://sdk.accountkit.com/en_US/sdk.js', ['jquery'], $versionAsset, true);

        wp_register_script('cpotp-process-login', CPOTP_PUBLIC . '/js/cp-otp-login.js', array('jquery', 'fb-account-kit'), $versionAsset, true);
        wp_register_script('cpotp-process-woo', CPOTP_PUBLIC . '/js/cp-otp-woo.js', array('jquery', 'fb-account-kit'), $versionAsset, true);
        wp_register_script('cpotp-auto-verify', CPOTP_PUBLIC . '/js/cp-otp-auto-popup.js', array('jquery', 'fb-account-kit'), $versionAsset, true);
        wp_register_script('cpotp-process-woo-download', CPOTP_PUBLIC . '/js/cp-otp-woo-download.js', array('jquery', 'fb-account-kit'), $versionAsset, true);
        wp_register_script('cpotp-process-cf7', CPOTP_PUBLIC . '/js/cp-otp-cf7.js', array('jquery', 'fb-account-kit'), $versionAsset, true);
        wp_register_script('cpotp-process-subscribe-to-download', CPOTP_PUBLIC . '/js/cp-otp-subscribe-to-download.js', array('jquery', 'fb-account-kit'), $versionAsset, true);
        wp_register_script('cpotp-process-shorcode-login', CPOTP_PUBLIC . '/js/cp-otp-shortcode-login.js', array('jquery', 'fb-account-kit'), $versionAsset, true);

        $variableCpOtp = array(
            'ajaxurl' => admin_url('admin-ajax.php'),
            'app_id' => isset($cp_otp_options['app_id']) ? $cp_otp_options['app_id'] : '',
            'app_display' => isset($cp_otp_options['app_display']) ? $cp_otp_options['app_display'] : '',
            'version' => isset($cp_otp_options['app_version']) ? $cp_otp_options['app_version'] : '',
            'nonce' => wp_create_nonce('cpotp-process-login'),
            'redirect' => esc_url(home_url('/?fb_account_kit_redir=true')),
            'get_query' => $_GET,
            'options' => $cp_otp_options,
            "redirect_after_login" => $redirect_to,
        );
        $variableCpOtp = apply_filters('cpotp-js-variable', $variableCpOtp);
        wp_localize_script('fb-account-kit', 'CpOtp', $variableCpOtp);
    }

    /**
     *
     */
    public function run()
    {
        new cpsmart_otp_ajax();

        $this->run_core();
    }


    private function run_core()
    {
        $cpCoreDemo = new CpCore('Smart OTP', [
            'plugin_path' => CPOTP_PATH,
            'plugin_id' => "23262583",
            'force_active' => false
        ]);


        $cpCoreDemo->createPageSetting([
            'callback' => [
                "page_title" => __cp("Smart OTP settings"),
                "menu_title" => __cp("Smart OTP"),
                "capability" => "manage_options",
                "menu_slug" => CPOTP_DASHBOARD_SLUG,
                "icon_url" => "",
                "prefix_options" => "cpotp_",
                'func' => "cp_otp_page_setting::general",
                "save_callback" => "cp_otp_page_setting::save_options_general",
            ]
        ]);


        $cpCoreDemo->createPageSetting([
            'callback' => [
                "page_title" => __cp("Smart OTP - Report"),
                "menu_title" => __cp("Smart OTP - Report"),
                "capability" => "manage_options",
                "menu_slug" => CPOTP_LOGS_SLUG,
                "icon_url" => "",
                "prefix_options" => "CpOTP_",
                'func' => "cp_otp_page_setting::logs",
            ]
        ]);
    }
}
